require File.expand_path('../spec_helper', __FILE__)

describe SourceValidator do
    describe 'functionality' do
      it 'external dependency that comes from a public source should be valid' do

        private_sources = [ "git@github.com:mercadolibre/mobile-ios_specs.git" ]
        private_specs = ["MyPod1", "MyPod1", "MyPod3"]

        stub_url = stub(:url => 'https://cdn.cocoapods.org/')
        spec_mock = mock()
        spec_mock.stubs(:spec_source).returns(stub_url)
        spec_mock.stubs(:defined_in_file).returns(nil?)
        spec_mock.stubs(:name).returns("MyExternalPod")
        
        validator = SourceValidator.new(private_specs, private_sources)
        filtered = validator.filter_dependency("MyExternalPod", [spec_mock])

        filtered.size.should.equal 1
      end

      it 'internal dependency that comes from a public source should not be valid' do
        private_sources = [ "git@github.com:mercadolibre/mobile-ios_specs.git" ]
        private_specs = ["MyPod1", "MyPod1", "MyPod3", "MyInternalPod"]

        stub_url = stub(:url => 'https://cdn.cocoapods.org/')
        spec_mock = mock()
        spec_mock.stubs(:spec_source).returns(stub_url)
        spec_mock.stubs(:defined_in_file).returns(nil?)
        spec_mock.stubs(:name).returns("MyInternalPod")
        
        validator = SourceValidator.new(private_specs, private_sources)
        filtered = validator.filter_dependency("MyInternalPod", [spec_mock])

        filtered.should.empty?
      end

      it 'internal dependency that comes from private source should be valid' do

        private_sources = [ "git@github.com:mercadolibre/mobile-ios_specs.git" ]
        private_specs = ["MyPod1", "MyPod1", "MyPod3", "MyInternalPod"]

        stub_url = stub(:url => 'git@github.com:mercadolibre/mobile-ios_specs.git')
        spec_mock = mock()
        spec_mock.stubs(:spec_source).returns(stub_url)
        spec_mock.stubs(:defined_in_file).returns(nil?)
        spec_mock.stubs(:name).returns("MyInternalPod")
        
        validator = SourceValidator.new(private_specs, private_sources)
        filtered = validator.filter_dependency("MyInternalPod", [spec_mock])

        filtered.size.should.equal 1
      end

      it 'development pods should be valid' do

        private_sources = [ "git@github.com:mercadolibre/mobile-ios_specs.git" ]
        private_specs = ["MyPod1", "MyPod1", "MyPod3", "MyInternalPod"]

        stub_url = stub(:url => '')
        spec_mock = mock()
        spec_mock.stubs(:spec_source).returns(stub_url)
        spec_mock.stubs(:defined_in_file).returns('./Users/Pods/Local Podspecs/MLMyDevelopmentPod.podspec')
        spec_mock.stubs(:name).returns("MLMyDevelopmentPod")
        
        validator = SourceValidator.new(private_specs, private_sources)
        filtered = validator.filter_dependency('MLMyDevelopmentPod', [spec_mock])

        filtered.size.should.equal 1
      end
    end
end
